@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: __init__.py - Last Update: 3/9/2023 Ver. 2.7.26 RC 1 - Author: cooldude2k $
+    $FileInfo: __init__.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -35,9 +35,10 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 // Source: http://en.wikipedia.org/wiki/Interleaved_2_of_5
 // Source: http://www.gs1au.org/assets/documents/info/user_manuals/barcode_technical_details/ITF_14_Barcode_Structure.pdf
 // Source: http://www.barcodeisland.com/
+// Source: https://web.archive.org/web/20201004174654/http://www.barcodeisland.com/
 '''
 
 from upcean.barcodes.barcode import *;
 from upcean.barcodes.shortcuts import *;
-from upcean.barcodes.files import *;
-from upcean.barcodes.downloader import *;
+from upcean.xml.files import *;
+from upcean.xml.downloader import *;
