@@ -11,11 +11,20 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: ean8.py - Last Update: 3/9/2023 Ver. 2.7.26 RC 1 - Author: cooldude2k $
+    $FileInfo: ean8.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
 import re, os, sys, types, upcean.barcodes.getsfname, upcean.support;
+try:
+ from io import StringIO, BytesIO;
+except ImportError:
+ try:
+  from cStringIO import StringIO;
+  from cStringIO import StringIO as BytesIO;
+ except ImportError:
+  from StringIO import StringIO;
+  from StringIO import StringIO as BytesIO;
 import upcean.barcodes.ean2, upcean.barcodes.ean5;
 pilsupport = upcean.support.check_for_pil();
 cairosupport = upcean.support.check_for_cairo();
@@ -33,17 +42,33 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
  imageoutlib = imageoutlib.lower();
  if(not pilsupport and imageoutlib=="pillow"):
   imageoutlib = "cairo";
- if(not cairosupport and imageoutlib=="cairo"):
+ if(not cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   imageoutlib = "pillow";
- if(imageoutlib!="pillow" and imageoutlib!="cairo"):
+ if(not cairosupport and imageoutlib=="cairosvg"):
+  imageoutlib = "pillow";
+ if(imageoutlib!="pillow" and imageoutlib!="cairo" and imageoutlib!="cairosvg"):
   imageoutlib = "pillow";
  if(not pilsupport and not cairosupport):
   return False;
- oldoutfile = upcean.barcodes.getsfname.get_save_filename(outfile, imageoutlib);
- if(isinstance(oldoutfile, tuple) or isinstance(oldoutfile, list)):
-  del(outfile);
-  outfile = oldoutfile[0];
-  outfileext = oldoutfile[1];
+ if(outfile is None):
+  if(imageoutlib=="cairosvg"):
+   oldoutfile = None;
+   outfile = None;
+   outfileext = "SVG";
+  else:
+   oldoutfile = None;
+   outfile = None;
+   outfileext = None;
+ else:
+  oldoutfile = upcean.barcodes.getsfname.get_save_filename(outfile, imageoutlib);
+  if(isinstance(oldoutfile, tuple) or isinstance(oldoutfile, list)):
+   del(outfile);
+   outfile = oldoutfile[0];
+   outfileext = oldoutfile[1];
+   if(cairosupport and imageoutlib=="cairo" and outfileext=="SVG"):
+    imageoutlib = "cairosvg";
+   if(cairosupport and imageoutlib=="cairosvg" and outfileext!="SVG"):
+    imageoutlib = "cairo";
  upc_pieces = None; 
  supplement = None;
  if(barwidth < 1): 
@@ -101,7 +126,7 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
  elif(pilsupport and imageoutlib=="pillow"):
   pil_addon_fix = 0;
   cairo_addon_fix = 0;
- elif(pilsupport and imageoutlib=="cairo"):
+ elif(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   pil_addon_fix = 0;
   cairo_addon_fix = (8 * (int(resize) ) );
  else:
@@ -130,11 +155,14 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
   upc_preimg = Image.new("RGB", ((83 * barwidth) + addonsize, barheight[1] + 9));
   upc_img = ImageDraw.Draw(upc_preimg);
   upc_img.rectangle([(0, 0), ((83 * barwidth) + addonsize, barheight[1] + 9)], fill=barcolor[2]);
- if(cairosupport and imageoutlib=="cairo"):
-  upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (83 * barwidth) + addonsize, barheight[1] + 8);
+ if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
+  if(outfileext=="SVG"):
+   upc_preimg = cairo.SVGSurface(None, (83 * barwidth) + addonsize, barheight[1] + 9);
+  else:
+   upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (83 * barwidth) + addonsize, barheight[1] + 9);
   upc_img = cairo.Context (upc_preimg);
   upc_img.set_antialias(cairo.ANTIALIAS_NONE);
-  upc_img.rectangle(0, 0, (83 * barwidth) + addonsize, barheight[1] + 8);
+  upc_img.rectangle(0, 0, (83 * barwidth) + addonsize, barheight[1] + 9);
   upc_img.set_source_rgb(barcolor[2][0], barcolor[2][1], barcolor[2][2]);
   upc_img.fill();
  upc_array = { 'upc': upc, 'code': [ ] };
@@ -146,10 +174,10 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
  start_bc_num_end = len(start_barcolor);
  LineSize = barheight[1];
  while(BarNum < start_bc_num_end):
-  if(BarNum<10):
-   LineSize = barheight[0];
-  else:
+  if(BarNum<12):
    LineSize = barheight[1];
+  else:
+   LineSize = barheight[0];
   if(hidetext):
    LineSize = barheight[1];
   if(start_barcolor[BarNum]==1):
@@ -345,13 +373,23 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
   del(upc_img);
   del(upc_preimg);
   upc_img = ImageDraw.Draw(new_upc_img);
- if(cairosupport and imageoutlib=="cairo"):
+ if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   upc_imgpat = cairo.SurfacePattern(upc_preimg);
   scaler = cairo.Matrix();
   scaler.scale(1/int(resize),1/int(resize));
   upc_imgpat.set_matrix(scaler);
   upc_imgpat.set_filter(cairo.FILTER_NEAREST);
-  new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((83 * barwidth) + addonsize) * int(resize), (barheight[1] + 9) * int(resize));
+  if(outfileext=="SVG"):
+   if(outfile is None):
+    svgoutfile = None;
+   else:
+    if(sys.version[0]=="2"):
+     svgoutfile = StringIO();
+    if(sys.version[0]>="3"):
+     svgoutfile = BytesIO();
+   new_upc_preimg = cairo.SVGSurface(svgoutfile, ((83 * barwidth) + addonsize) * int(resize), (barheight[1] + 9) * int(resize));
+  else:
+   new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((83 * barwidth) + addonsize) * int(resize), (barheight[1] + 9) * int(resize));
   new_upc_img = cairo.Context(new_upc_preimg);
   new_upc_img.set_source(upc_imgpat);
   new_upc_img.paint();
@@ -359,16 +397,16 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
  if(not hidetext):
   if(hidesn is not None and not hidesn):
    drawColorText(upc_img, 10 * int(resize), (1 + (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[0] * int(resize)), "<", barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (11 + (14 * (int(resize) - 1)) - (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftLeftDigit)[0], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (17 + (19 * (int(resize) - 1)) - (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftLeftDigit)[1], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (24 + (24 * (int(resize) - 1)) + (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftRightDigit)[0], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (30 + (29 * (int(resize) - 1)) + (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftRightDigit)[1], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (43 + (46 * (int(resize) - 1)) - (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightLeftDigit)[0], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (49 + (51 * (int(resize) - 1)) - (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightLeftDigit)[1], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (56 + (56 * (int(resize) - 1)) + (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightRightDigit)[0], barcolor[1], "ocrb", imageoutlib);
-  drawColorText(upc_img, 10 * int(resize), (62 + (61 * (int(resize) - 1)) + (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightRightDigit)[1], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (13 + (14 * (int(resize) - 1)) - (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftLeftDigit)[0], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (19 + (19 * (int(resize) - 1)) - (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftLeftDigit)[1], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (26 + (24 * (int(resize) - 1)) + (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftRightDigit)[0], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (32 + (29 * (int(resize) - 1)) + (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(LeftRightDigit)[1], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (45 + (46 * (int(resize) - 1)) - (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightLeftDigit)[0], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (51 + (51 * (int(resize) - 1)) - (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightLeftDigit)[1], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (58 + (56 * (int(resize) - 1)) + (1 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightRightDigit)[0], barcolor[1], "ocrb", imageoutlib);
+  drawColorText(upc_img, 10 * int(resize), (64 + (61 * (int(resize) - 1)) + (3 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[1] * int(resize)), list(RightRightDigit)[1], barcolor[1], "ocrb", imageoutlib);
   if(hidecd is not None and not hidecd):
-   drawColorText(upc_img, 10 * int(resize), (75 + (75 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[2] * int(resize)), ">", barcolor[1], "ocrb", imageoutlib);
+   drawColorText(upc_img, 10 * int(resize), (77 + (75 * (int(resize) - 1))) * barwidth, cairo_addon_fix + (barheight[0] + (barheight[0] * (int(resize) - 1)) + pil_addon_fix) + (textxy[2] * int(resize)), ">", barcolor[1], "ocrb", imageoutlib);
  del(upc_img);
  if(pilsupport and imageoutlib=="pillow"):
   if(supplement is not None and len(supplement)==2): 
@@ -381,7 +419,7 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
    if(upc_sup_img):
     new_upc_img.paste(upc_sup_img,((83 * barwidth) * int(resize), 0));
     del(upc_sup_img);
- if(cairosupport and imageoutlib=="cairo"):
+ if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   if(supplement!=None and len(supplement)==2):
    upc_sup_img = upcean.barcodes.ean2.draw_ean2_barcode_supplement(supplement,resize,hideinfo,barheight,barwidth,textxy,barcolor,imageoutlib);
    new_upc_img.set_source_surface(upc_sup_img, (83 * barwidth) * int(resize), 0);
@@ -395,36 +433,72 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
  if(oldoutfile is None or isinstance(oldoutfile, bool)):
   if(pilsupport and imageoutlib=="pillow"):
    return new_upc_img;
-  if(cairosupport and imageoutlib=="cairo"):
+  if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
    return new_upc_preimg;
  if(sys.version[0]=="2"):
   if(outfile=="-" or outfile=="" or outfile==" " or outfile is None):
+   stdoutfile = StringIO();
    try:
     if(pilsupport and imageoutlib=="pillow"):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.fileno(), new_upc_img.tobytes());
+      stdoutfile.write(new_upc_img.tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_img.save(sys.stdout, outfileext);
-    if(cairosupport and imageoutlib=="cairo"):
+      new_upc_img.save(stdoutfile, outfileext);
+      stdoutfile.seek(0);
+      return stdoutfile;
+    if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.fileno(), new_upc_preimg.get_data().tobytes());
+      stdoutfile.write(new_upc_preimg.get_data().tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
+     elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
+      new_upc_preimg.flush();
+      new_upc_preimg.finish(); 
+      svgoutfile.seek(0);
+      svgouttext = svgoutfile.read();
+      stdoutfile.write(svgouttext);
+      svgoutfile.close();
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_preimg.write_to_png(sys.stdout);
+      new_upc_preimg.write_to_png(stdoutfile);
+      stdoutfile.seek(0);
+      return stdoutfile;
    except:
     return False;
  if(sys.version[0]>="3"):
+  stdoutfile = BytesIO();
   if(outfile=="-" or outfile=="" or outfile==" " or outfile is None):
    try:
     if(pilsupport and imageoutlib=="pillow"):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.buffer.fileno(), new_upc_img.tobytes());
+      stdoutfile.write(new_upc_img.tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_img.save(sys.stdout.buffer, outfileext);
-    if(cairosupport and imageoutlib=="cairo"):
+      new_upc_img.save(stdoutfile, outfileext);
+      stdoutfile.seek(0);
+      return stdoutfile;
+    if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.buffer.fileno(), new_upc_preimg.get_data().tobytes());
+      stdoutfile.write(new_upc_preimg.get_data().tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
+     elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
+      new_upc_preimg.flush();
+      new_upc_preimg.finish(); 
+      svgoutfile.seek(0);
+      svgouttext = svgoutfile.read();
+      stdoutfile.write(svgouttext);
+      svgoutfile.close();
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_preimg.write_to_png(sys.stdout.buffer);
+      new_upc_preimg.write_to_png(stdoutfile);
+      stdoutfile.seek(0);
+      return stdoutfile;
    except:
     return False;
  if(outfile!="-" and outfile!="" and outfile!=" "):
@@ -435,12 +509,22 @@ def create_ean8_barcode(upc,outfile="./ean8.png",resize=1,hideinfo=(False, False
       f.write(new_upc_img.tobytes());
     else:
      new_upc_img.save(outfile, outfileext);
-   if(cairosupport and imageoutlib=="cairo"):
+   if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
     if(outfileext=="BYTES"):
      with open(outfile, 'wb+') as f:
       f.write(new_upc_preimg.get_data().tobytes());
+     return True;
+    elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
+     new_upc_preimg.flush();
+     new_upc_preimg.finish(); 
+     svgoutfile.seek(0);
+     svgouttext = svgoutfile.read();
+     with open(outfile, 'wb+') as f:
+      f.write(svgouttext);
+     return True;
     else:
      new_upc_preimg.write_to_png(outfile);
+     return True;
   except:
    return False;
  return True;
