@@ -11,7 +11,7 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: getsfname.py - Last Update: 3/9/2023 Ver. 2.7.26 RC 1 - Author: cooldude2k $
+    $FileInfo: getsfname.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
@@ -23,9 +23,11 @@ def get_save_filename(outfile, imageoutlib="pillow"):
  imageoutlib = imageoutlib.lower();
  if(not pilsupport and imageoutlib=="pillow"):
   imageoutlib = "cairo";
- if(not cairosupport and imageoutlib=="cairo"):
+ if(not cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   imageoutlib = "pillow";
- if(imageoutlib!="pillow" and imageoutlib!="cairo"):
+ if(not cairosupport and imageoutlib=="cairosvg"):
+  imageoutlib = "pillow";
+ if(imageoutlib!="pillow" and imageoutlib!="cairo" and imageoutlib!="cairosvg"):
   imageoutlib = "pillow";
  if(not pilsupport and not cairosupport):
   return False;
@@ -75,6 +77,8 @@ def get_save_filename(outfile, imageoutlib="pillow"):
    else:
     if(outfileext=="BYTES"):
      outfileext = "BYTES";
+    elif(outfileext=="SVG"):
+     outfileext = "SVG";
     else:
      outfileext = "PNG";
    return (outfile, outfileext.upper());   
@@ -112,6 +116,8 @@ def get_save_filename(outfile, imageoutlib="pillow"):
    else:
     if(outfileext=="BYTES"):
      outfileext = "BYTES";
+    elif(outfileext=="SVG"):
+     outfileext = "SVG";
     else:
      outfileext = "PNG";
    return (outfile, outfileext.upper());
