@@ -11,11 +11,20 @@
     Copyright 2011-2023 Game Maker 2k - https://github.com/GameMaker2k
     Copyright 2011-2023 Kazuki Przyborowski - https://github.com/KazukiPrzyborowski
 
-    $FileInfo: msi.py - Last Update: 3/9/2023 Ver. 2.7.26 RC 1 - Author: cooldude2k $
+    $FileInfo: msi.py - Last Update: 3/9/2023 Ver. 2.7.27 RC 1 - Author: cooldude2k $
 '''
 
 from __future__ import absolute_import, division, print_function, unicode_literals;
 import re, os, sys, types, upcean.barcodes.getsfname, upcean.support;
+try:
+ from io import StringIO, BytesIO;
+except ImportError:
+ try:
+  from cStringIO import StringIO;
+  from cStringIO import StringIO as BytesIO;
+ except ImportError:
+  from StringIO import StringIO;
+  from StringIO import StringIO as BytesIO;
 pilsupport = upcean.support.check_for_pil();
 cairosupport = upcean.support.check_for_cairo();
 from upcean.barcodes.predraw import *;
@@ -32,17 +41,33 @@ def create_msi_barcode(upc,outfile="./msi.png",resize=1,hideinfo=(False, False,
  imageoutlib = imageoutlib.lower();
  if(not pilsupport and imageoutlib=="pillow"):
   imageoutlib = "cairo";
- if(not cairosupport and imageoutlib=="cairo"):
+ if(not cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   imageoutlib = "pillow";
- if(imageoutlib!="pillow" and imageoutlib!="cairo"):
+ if(not cairosupport and imageoutlib=="cairosvg"):
+  imageoutlib = "pillow";
+ if(imageoutlib!="pillow" and imageoutlib!="cairo" and imageoutlib!="cairosvg"):
   imageoutlib = "pillow";
  if(not pilsupport and not cairosupport):
   return False;
- oldoutfile = upcean.barcodes.getsfname.get_save_filename(outfile, imageoutlib);
- if(isinstance(oldoutfile, tuple) or isinstance(oldoutfile, list)):
-  del(outfile);
-  outfile = oldoutfile[0];
-  outfileext = oldoutfile[1];
+ if(outfile is None):
+  if(imageoutlib=="cairosvg"):
+   oldoutfile = None;
+   outfile = None;
+   outfileext = "SVG";
+  else:
+   oldoutfile = None;
+   outfile = None;
+   outfileext = None;
+ else:
+  oldoutfile = upcean.barcodes.getsfname.get_save_filename(outfile, imageoutlib);
+  if(isinstance(oldoutfile, tuple) or isinstance(oldoutfile, list)):
+   del(outfile);
+   outfile = oldoutfile[0];
+   outfileext = oldoutfile[1];
+   if(cairosupport and imageoutlib=="cairo" and outfileext=="SVG"):
+    imageoutlib = "cairosvg";
+   if(cairosupport and imageoutlib=="cairosvg" and outfileext!="SVG"):
+    imageoutlib = "cairo";
  if(barwidth < 1): 
   barwidth = 1;
  if(len(upc) < 1): 
@@ -91,7 +116,7 @@ def create_msi_barcode(upc,outfile="./msi.png",resize=1,hideinfo=(False, False,
  elif(pilsupport and imageoutlib=="pillow"):
   pil_addon_fix = 0;
   cairo_addon_fix = 0;
- elif(pilsupport and imageoutlib=="cairo"):
+ elif(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   pil_addon_fix = 0;
   cairo_addon_fix = (8 * (int(resize) ) );
  else:
@@ -121,11 +146,14 @@ def create_msi_barcode(upc,outfile="./msi.png",resize=1,hideinfo=(False, False,
   upc_preimg = Image.new("RGB", ((34 * barwidth) + upc_size_add, barheight[1] + 9));
   upc_img = ImageDraw.Draw(upc_preimg);
   upc_img.rectangle([(0, 0), ((34 * barwidth) + upc_size_add, barheight[1] + 9)], fill=barcolor[2]);
- if(cairosupport and imageoutlib=="cairo"):
-  upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (34 * barwidth) + upc_size_add, barheight[1] + 8);
+ if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
+  if(outfileext=="SVG"):
+   upc_preimg = cairo.SVGSurface(None, (34 * barwidth) + upc_size_add, barheight[1] + 9);
+  else:
+   upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, (34 * barwidth) + upc_size_add, barheight[1] + 9);
   upc_img = cairo.Context (upc_preimg);
   upc_img.set_antialias(cairo.ANTIALIAS_NONE);
-  upc_img.rectangle(0, 0, (34 * barwidth) + upc_size_add, barheight[1] + 8);
+  upc_img.rectangle(0, 0, (34 * barwidth) + upc_size_add, barheight[1] + 9);
   upc_img.set_source_rgb(barcolor[2][0], barcolor[2][1], barcolor[2][2]);
   upc_img.fill();
  upc_array = { 'upc': upc, 'code': [ ] };
@@ -192,13 +220,23 @@ def create_msi_barcode(upc,outfile="./msi.png",resize=1,hideinfo=(False, False,
   del(upc_img);
   del(upc_preimg);
   upc_img = ImageDraw.Draw(new_upc_img);
- if(cairosupport and imageoutlib=="cairo"):
+ if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
   upc_imgpat = cairo.SurfacePattern(upc_preimg);
   scaler = cairo.Matrix();
   scaler.scale(1/int(resize),1/int(resize));
   upc_imgpat.set_matrix(scaler);
   upc_imgpat.set_filter(cairo.FILTER_NEAREST);
-  new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((34 * barwidth) + upc_size_add) * int(resize), (barheight[1] + 9) * int(resize));
+  if(outfileext=="SVG"):
+   if(outfile is None):
+    svgoutfile = None;
+   else:
+    if(sys.version[0]=="2"):
+     svgoutfile = StringIO();
+    if(sys.version[0]>="3"):
+     svgoutfile = BytesIO();
+   new_upc_preimg = cairo.SVGSurface(svgoutfile, ((34 * barwidth) + upc_size_add) * int(resize), (barheight[1] + 9) * int(resize));
+  else:
+   new_upc_preimg = cairo.ImageSurface(cairo.FORMAT_RGB24, ((34 * barwidth) + upc_size_add) * int(resize), (barheight[1] + 9) * int(resize));
   new_upc_img = cairo.Context(new_upc_preimg);
   new_upc_img.set_source(upc_imgpat);
   new_upc_img.paint();
@@ -214,36 +252,72 @@ def create_msi_barcode(upc,outfile="./msi.png",resize=1,hideinfo=(False, False,
  if(oldoutfile is None or isinstance(oldoutfile, bool)):
   if(pilsupport and imageoutlib=="pillow"):
    return new_upc_img;
-  if(cairosupport and imageoutlib=="cairo"):
+  if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
    return new_upc_preimg;
  if(sys.version[0]=="2"):
   if(outfile=="-" or outfile=="" or outfile==" " or outfile is None):
+   stdoutfile = StringIO();
    try:
     if(pilsupport and imageoutlib=="pillow"):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.fileno(), new_upc_img.tobytes());
+      stdoutfile.write(new_upc_img.tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_img.save(sys.stdout, outfileext);
-    if(cairosupport and imageoutlib=="cairo"):
+      new_upc_img.save(stdoutfile, outfileext);
+      stdoutfile.seek(0);
+      return stdoutfile;
+    if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.fileno(), new_upc_preimg.get_data().tobytes());
+      stdoutfile.write(new_upc_preimg.get_data().tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
+     elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
+      new_upc_preimg.flush();
+      new_upc_preimg.finish(); 
+      svgoutfile.seek(0);
+      svgouttext = svgoutfile.read();
+      stdoutfile.write(svgouttext);
+      svgoutfile.close();
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_preimg.write_to_png(sys.stdout);
+      new_upc_preimg.write_to_png(stdoutfile);
+      stdoutfile.seek(0);
+      return stdoutfile;
    except:
     return False;
  if(sys.version[0]>="3"):
+  stdoutfile = BytesIO();
   if(outfile=="-" or outfile=="" or outfile==" " or outfile is None):
    try:
     if(pilsupport and imageoutlib=="pillow"):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.buffer.fileno(), new_upc_img.tobytes());
+      stdoutfile.write(new_upc_img.tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_img.save(sys.stdout.buffer, outfileext);
-    if(cairosupport and imageoutlib=="cairo"):
+      new_upc_img.save(stdoutfile, outfileext);
+      stdoutfile.seek(0);
+      return stdoutfile;
+    if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
      if(outfileext=="BYTES"):
-      os.write(sys.stdout.buffer.fileno(), new_upc_preimg.get_data().tobytes());
+      stdoutfile.write(new_upc_preimg.get_data().tobytes());
+      stdoutfile.seek(0);
+      return stdoutfile;
+     elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
+      new_upc_preimg.flush();
+      new_upc_preimg.finish(); 
+      svgoutfile.seek(0);
+      svgouttext = svgoutfile.read();
+      stdoutfile.write(svgouttext);
+      svgoutfile.close();
+      stdoutfile.seek(0);
+      return stdoutfile;
      else:
-      new_upc_preimg.write_to_png(sys.stdout.buffer);
+      new_upc_preimg.write_to_png(stdoutfile);
+      stdoutfile.seek(0);
+      return stdoutfile;
    except:
     return False;
  if(outfile!="-" and outfile!="" and outfile!=" "):
@@ -254,12 +328,22 @@ def create_msi_barcode(upc,outfile="./msi.png",resize=1,hideinfo=(False, False,
       f.write(new_upc_img.tobytes());
     else:
      new_upc_img.save(outfile, outfileext);
-   if(cairosupport and imageoutlib=="cairo"):
+   if(cairosupport and (imageoutlib=="cairo" or imageoutlib=="cairosvg")):
     if(outfileext=="BYTES"):
      with open(outfile, 'wb+') as f:
       f.write(new_upc_preimg.get_data().tobytes());
+     return True;
+    elif(outfileext=="SVG" or imageoutlib=="cairosvg"):
+     new_upc_preimg.flush();
+     new_upc_preimg.finish(); 
+     svgoutfile.seek(0);
+     svgouttext = svgoutfile.read();
+     with open(outfile, 'wb+') as f:
+      f.write(svgouttext);
+     return True;
     else:
      new_upc_preimg.write_to_png(outfile);
+     return True;
   except:
    return False;
  return True;
