@@ -31,3 +31,13 @@ def class_barcode(type=None, code=None):
  if(type not in upcean.support.supported_barcodes("tuple")):
   return False;
  return upcean.oopfuncs.oopfuncs.barcode(type, code);
+
+def barcode_decode(type=None, filename=None):
+ if(type not in upcean.support.supported_barcodes("tuple")):
+  return False;
+ return upcean.oopfuncs.oopfuncs.decode(type, filename);
+
+def decode_barcode(type=None, code=None):
+ if(type not in upcean.support.supported_barcodes("tuple")):
+  return False;
+ return upcean.oopfuncs.oopfuncs.decode(type, filename);
